diff -u -r -N squid-3.4.1/ChangeLog squid-3.4.2/ChangeLog
--- squid-3.4.1/ChangeLog	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/ChangeLog	2013-12-31 00:33:27.000000000 +1300
@@ -1,3 +1,15 @@
+Changes to squid-3.4.2 (30 Dec 2013):
+
+	- Regression Bug 3980: FATAL ERROR due to max_user_ip -s option
+	- Regression Fix: \-unescaping in quoted strings from helpers
+	- Regression Fix: URL helper API bypassing on URL containing '=' character
+	- Bug 3985: 60s limit introduced by balance_on_multiple_ip breaks bad IP recovery
+	- Bug 3806: Caching responses with Vary header
+	- Bug 3498: FTP PUT assertion
+	- WCCPv2: Fix assertion 'Cannot convert non-IPv4 to IPv4' on FreeBSD
+	- Enable concurrency by default for SSL certificate validator
+	- ... and fix several build errors
+
 Changes to squid-3.4.1 (09 Dec 2013):
 
 	- Bug 3935: Invalid pointer dereference when peeking at origin server certificate
diff -u -r -N squid-3.4.1/compat/eui64_aton.c squid-3.4.2/compat/eui64_aton.c
--- squid-3.4.1/compat/eui64_aton.c	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/compat/eui64_aton.c	2013-12-31 00:33:27.000000000 +1300
@@ -77,6 +77,8 @@
 #include "squid.h"
 #include "compat/eui64_aton.h"
 
+#if SQUID_EUI64_ATON
+
 /*
  * Convert an ASCII representation of an EUI-64 to binary form.
  */
@@ -132,3 +134,5 @@
 
     return (0);
 }
+
+#endif /* !SQUID_EUI64_ATON */
diff -u -r -N squid-3.4.1/compat/eui64_aton.h squid-3.4.2/compat/eui64_aton.h
--- squid-3.4.1/compat/eui64_aton.h	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/compat/eui64_aton.h	2013-12-31 00:33:27.000000000 +1300
@@ -46,6 +46,8 @@
 extern "C" {
 #endif
 
+#define SQUID_EUI64_ATON 1
+
     /**
      * Size of the ASCII representation of an EUI-64.
      */
diff -u -r -N squid-3.4.1/compat/Makefile.am squid-3.4.2/compat/Makefile.am
--- squid-3.4.1/compat/Makefile.am	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/compat/Makefile.am	2013-12-31 00:33:27.000000000 +1300
@@ -9,8 +9,8 @@
 
 # Port Specific Configurations
 
-noinst_LIBRARIES = libcompat-squid.a
-libcompat_squid_a_SOURCES = \
+noinst_LTLIBRARIES = libcompat-squid.la
+libcompat_squid_la_SOURCES = \
 	assert.cc \
 	assert.h \
 	cmsg.h \
@@ -23,6 +23,7 @@
 	debug.h \
 	drand48.h \
 	eui64_aton.h \
+	eui64_aton.c \
 	fdsetsize.h \
 	getaddrinfo.h \
 	getnameinfo.h \
@@ -74,7 +75,7 @@
 	os/solaris.h \
 	os/sunos.h
 
-libcompat_squid_a_LIBADD= $(LIBOBJS)
+libcompat_squid_la_LIBADD= $(LIBOBJS)
 
 check_PROGRAMS += testPreCompiler
 TESTS += testPreCompiler
diff -u -r -N squid-3.4.1/compat/Makefile.in squid-3.4.2/compat/Makefile.in
--- squid-3.4.1/compat/Makefile.in	2013-12-09 14:21:25.000000000 +1300
+++ squid-3.4.2/compat/Makefile.in	2013-12-31 00:33:49.000000000 +1300
@@ -39,9 +39,9 @@
 build_triplet = @build@
 host_triplet = @host@
 DIST_COMMON = $(srcdir)/Makefile.am $(srcdir)/Makefile.in \
-	$(top_srcdir)/src/Common.am drand48.c eui64_aton.c \
-	getaddrinfo.c getnameinfo.c inet_ntop.c inet_pton.c \
-	initgroups.c psignal.c strerror.c strsep.c strtoll.c tempnam.c
+	$(top_srcdir)/src/Common.am drand48.c getaddrinfo.c \
+	getnameinfo.c inet_ntop.c inet_pton.c initgroups.c psignal.c \
+	strerror.c strsep.c strtoll.c tempnam.c
 check_PROGRAMS = testPreCompiler$(EXEEXT)
 TESTS = testPreCompiler$(EXEEXT) testHeaders
 @USE_LOADABLE_MODULES_TRUE@am__append_1 = $(INCLTDL)
@@ -109,16 +109,12 @@
 CONFIG_HEADER = $(top_builddir)/include/autoconf.h
 CONFIG_CLEAN_FILES =
 CONFIG_CLEAN_VPATH_FILES =
-LIBRARIES = $(noinst_LIBRARIES)
-ARFLAGS = cru
-libcompat_squid_a_AR = $(AR) $(ARFLAGS)
-libcompat_squid_a_DEPENDENCIES = $(LIBOBJS)
-am_libcompat_squid_a_OBJECTS = assert.$(OBJEXT) compat.$(OBJEXT) \
-	debug.$(OBJEXT) GnuRegex.$(OBJEXT) shm.$(OBJEXT) \
-	strnstr.$(OBJEXT) strnrchr.$(OBJEXT) xalloc.$(OBJEXT) \
-	xstrerror.$(OBJEXT) xstring.$(OBJEXT) xstrto.$(OBJEXT) \
-	mswindows.$(OBJEXT)
-libcompat_squid_a_OBJECTS = $(am_libcompat_squid_a_OBJECTS)
+LTLIBRARIES = $(noinst_LTLIBRARIES)
+libcompat_squid_la_DEPENDENCIES = $(LIBOBJS)
+am_libcompat_squid_la_OBJECTS = assert.lo compat.lo debug.lo \
+	eui64_aton.lo GnuRegex.lo shm.lo strnstr.lo strnrchr.lo \
+	xalloc.lo xstrerror.lo xstring.lo xstrto.lo mswindows.lo
+libcompat_squid_la_OBJECTS = $(am_libcompat_squid_la_OBJECTS)
 am_testPreCompiler_OBJECTS = testPreCompiler.$(OBJEXT) \
 	testMain.$(OBJEXT)
 testPreCompiler_OBJECTS = $(am_testPreCompiler_OBJECTS)
@@ -150,8 +146,9 @@
 CXXLINK = $(LIBTOOL) --tag=CXX $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
 	--mode=link $(CXXLD) $(AM_CXXFLAGS) $(CXXFLAGS) $(AM_LDFLAGS) \
 	$(LDFLAGS) -o $@
-SOURCES = $(libcompat_squid_a_SOURCES) $(testPreCompiler_SOURCES)
-DIST_SOURCES = $(libcompat_squid_a_SOURCES) $(testPreCompiler_SOURCES)
+SOURCES = $(libcompat_squid_la_SOURCES) $(testPreCompiler_SOURCES)
+DIST_SOURCES = $(libcompat_squid_la_SOURCES) \
+	$(testPreCompiler_SOURCES)
 ETAGS = etags
 CTAGS = ctags
 am__tty_colors = \
@@ -378,14 +375,14 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 
 # Ideally this would be 100% inline functions and macro wrappers.
 
 # Port Specific Configurations
-noinst_LIBRARIES = libcompat-squid.a
-libcompat_squid_a_SOURCES = \
+noinst_LTLIBRARIES = libcompat-squid.la
+libcompat_squid_la_SOURCES = \
 	assert.cc \
 	assert.h \
 	cmsg.h \
@@ -398,6 +395,7 @@
 	debug.h \
 	drand48.h \
 	eui64_aton.h \
+	eui64_aton.c \
 	fdsetsize.h \
 	getaddrinfo.h \
 	getnameinfo.h \
@@ -449,7 +447,7 @@
 	os/solaris.h \
 	os/sunos.h
 
-libcompat_squid_a_LIBADD = $(LIBOBJS)
+libcompat_squid_la_LIBADD = $(LIBOBJS)
 testPreCompiler_SOURCES = \
 	testPreCompiler.h \
 	testPreCompiler.cc \
@@ -492,12 +490,16 @@
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
 $(am__aclocal_m4_deps):
 
-clean-noinstLIBRARIES:
-	-test -z "$(noinst_LIBRARIES)" || rm -f $(noinst_LIBRARIES)
-libcompat-squid.a: $(libcompat_squid_a_OBJECTS) $(libcompat_squid_a_DEPENDENCIES) 
-	-rm -f libcompat-squid.a
-	$(libcompat_squid_a_AR) libcompat-squid.a $(libcompat_squid_a_OBJECTS) $(libcompat_squid_a_LIBADD)
-	$(RANLIB) libcompat-squid.a
+clean-noinstLTLIBRARIES:
+	-test -z "$(noinst_LTLIBRARIES)" || rm -f $(noinst_LTLIBRARIES)
+	@list='$(noinst_LTLIBRARIES)'; for p in $$list; do \
+	  dir="`echo $$p | sed -e 's|/[^/]*$$||'`"; \
+	  test "$$dir" != "$$p" || dir=.; \
+	  echo "rm -f \"$${dir}/so_locations\""; \
+	  rm -f "$${dir}/so_locations"; \
+	done
+libcompat-squid.la: $(libcompat_squid_la_OBJECTS) $(libcompat_squid_la_DEPENDENCIES) 
+	$(CXXLINK)  $(libcompat_squid_la_OBJECTS) $(libcompat_squid_la_LIBADD) $(LIBS)
 
 clean-checkPROGRAMS:
 	@list='$(check_PROGRAMS)'; test -n "$$list" || exit 0; \
@@ -518,7 +520,6 @@
 	-rm -f *.tab.c
 
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/drand48.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/eui64_aton.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/getaddrinfo.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/getnameinfo.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/inet_ntop.Po@am__quote@
@@ -529,20 +530,21 @@
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/strsep.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/strtoll.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@$(DEPDIR)/tempnam.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/GnuRegex.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/assert.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/compat.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/debug.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mswindows.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/shm.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strnrchr.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strnstr.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/GnuRegex.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/assert.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/compat.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/debug.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/eui64_aton.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mswindows.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/shm.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strnrchr.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/strnstr.Plo@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/testMain.Po@am__quote@
 @AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/testPreCompiler.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xalloc.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xstrerror.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xstring.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xstrto.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xalloc.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xstrerror.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xstring.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/xstrto.Plo@am__quote@
 
 .c.o:
 @am__fastdepCC_TRUE@	$(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
@@ -784,7 +786,7 @@
 	$(MAKE) $(AM_MAKEFLAGS) $(check_PROGRAMS)
 	$(MAKE) $(AM_MAKEFLAGS) check-TESTS
 check: check-am
-all-am: Makefile $(LIBRARIES)
+all-am: Makefile $(LTLIBRARIES)
 installdirs:
 install: install-am
 install-exec: install-exec-am
@@ -815,7 +817,7 @@
 clean: clean-am
 
 clean-am: clean-checkPROGRAMS clean-generic clean-libtool \
-	clean-noinstLIBRARIES mostlyclean-am
+	clean-noinstLTLIBRARIES mostlyclean-am
 
 distclean: distclean-am
 	-rm -rf $(DEPDIR) ./$(DEPDIR)
@@ -887,7 +889,7 @@
 
 .PHONY: CTAGS GTAGS all all-am check check-TESTS check-am clean \
 	clean-checkPROGRAMS clean-generic clean-libtool \
-	clean-noinstLIBRARIES ctags distclean distclean-compile \
+	clean-noinstLTLIBRARIES ctags distclean distclean-compile \
 	distclean-generic distclean-libtool distclean-tags distdir dvi \
 	dvi-am html html-am info info-am install install-am \
 	install-data install-data-am install-dvi install-dvi-am \
diff -u -r -N squid-3.4.1/configure squid-3.4.2/configure
--- squid-3.4.1/configure	2013-12-09 14:22:01.000000000 +1300
+++ squid-3.4.2/configure	2013-12-31 00:34:14.000000000 +1300
@@ -1,7 +1,7 @@
 #! /bin/sh
 # From configure.ac Revision.
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.68 for Squid Web Proxy 3.4.1.
+# Generated by GNU Autoconf 2.68 for Squid Web Proxy 3.4.2.
 #
 # Report bugs to <http://bugs.squid-cache.org/>.
 #
@@ -575,8 +575,8 @@
 # Identity of this package.
 PACKAGE_NAME='Squid Web Proxy'
 PACKAGE_TARNAME='squid'
-PACKAGE_VERSION='3.4.1'
-PACKAGE_STRING='Squid Web Proxy 3.4.1'
+PACKAGE_VERSION='3.4.2'
+PACKAGE_STRING='Squid Web Proxy 3.4.2'
 PACKAGE_BUGREPORT='http://bugs.squid-cache.org/'
 PACKAGE_URL=''
 
@@ -1579,7 +1579,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures Squid Web Proxy 3.4.1 to adapt to many kinds of systems.
+\`configure' configures Squid Web Proxy 3.4.2 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1649,7 +1649,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of Squid Web Proxy 3.4.1:";;
+     short | recursive ) echo "Configuration of Squid Web Proxy 3.4.2:";;
    esac
   cat <<\_ACEOF
 
@@ -2037,7 +2037,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-Squid Web Proxy configure 3.4.1
+Squid Web Proxy configure 3.4.2
 generated by GNU Autoconf 2.68
 
 Copyright (C) 2010 Free Software Foundation, Inc.
@@ -3133,7 +3133,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by Squid Web Proxy $as_me 3.4.1, which was
+It was created by Squid Web Proxy $as_me 3.4.2, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   $ $0 $@
@@ -3952,7 +3952,7 @@
 
 # Define the identity of the package.
  PACKAGE='squid'
- VERSION='3.4.1'
+ VERSION='3.4.2'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -20855,7 +20855,7 @@
 fi
 
 if test "x$enable_snmp" = "xyes"; then
-    SNMPLIB='../snmplib/libsnmplib.a'
+    SNMPLIB='../snmplib/libsnmplib.la'
     makesnmplib=snmplib
 fi
 { $as_echo "$as_me:${as_lineno-$LINENO}: SNMP support enabled: $enable_snmp" >&5
@@ -30537,6 +30537,7 @@
 	bswap_32 \
 	bswap16 \
 	bswap32 \
+	eui64_aton \
 	fchmod \
 	getdtablesize \
 	getpagesize \
@@ -30615,19 +30616,6 @@
 
 fi
 
-ac_fn_cxx_check_func "$LINENO" "eui64_aton" "ac_cv_func_eui64_aton"
-if test "x$ac_cv_func_eui64_aton" = xyes; then :
-  $as_echo "#define HAVE_EUI64_ATON 1" >>confdefs.h
-
-else
-  case " $LIBOBJS " in
-  *" eui64_aton.$ac_objext "* ) ;;
-  *) LIBOBJS="$LIBOBJS eui64_aton.$ac_objext"
- ;;
-esac
-
-fi
-
 ac_fn_cxx_check_func "$LINENO" "inet_ntop" "ac_cv_func_inet_ntop"
 if test "x$ac_cv_func_inet_ntop" = xyes; then :
   $as_echo "#define HAVE_INET_NTOP 1" >>confdefs.h
@@ -33133,7 +33121,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by Squid Web Proxy $as_me 3.4.1, which was
+This file was extended by Squid Web Proxy $as_me 3.4.2, which was
 generated by GNU Autoconf 2.68.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -33199,7 +33187,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-Squid Web Proxy config.status 3.4.1
+Squid Web Proxy config.status 3.4.2
 configured by $0, generated by GNU Autoconf 2.68,
   with options \\"\$ac_cs_config\\"
 
diff -u -r -N squid-3.4.1/configure.ac squid-3.4.2/configure.ac
--- squid-3.4.1/configure.ac	2013-12-09 14:22:01.000000000 +1300
+++ squid-3.4.2/configure.ac	2013-12-31 00:34:14.000000000 +1300
@@ -1,4 +1,4 @@
-AC_INIT([Squid Web Proxy],[3.4.1],[http://bugs.squid-cache.org/],[squid])
+AC_INIT([Squid Web Proxy],[3.4.2],[http://bugs.squid-cache.org/],[squid])
 AC_PREREQ(2.61)
 AC_CONFIG_HEADERS([include/autoconf.h])
 AC_CONFIG_AUX_DIR(cfgaux)
@@ -1138,7 +1138,7 @@
    [Define to enable SNMP monitoring of Squid])
 AM_CONDITIONAL(ENABLE_SNMP, [test "x$enable_snmp" = "xyes"])
 if test "x$enable_snmp" = "xyes"; then
-    SNMPLIB='../snmplib/libsnmplib.a'
+    SNMPLIB='../snmplib/libsnmplib.la'
     makesnmplib=snmplib
 fi
 AC_MSG_NOTICE([SNMP support enabled: $enable_snmp])
@@ -3057,6 +3057,7 @@
 	bswap_32 \
 	bswap16 \
 	bswap32 \
+	eui64_aton \
 	fchmod \
 	getdtablesize \
 	getpagesize \
@@ -3114,7 +3115,6 @@
 dnl ... and some we provide local replacements for
 AC_REPLACE_FUNCS(\
 	drand48 \
-	eui64_aton \
 	inet_ntop \
 	inet_pton \
 	initgroups \
diff -u -r -N squid-3.4.1/helpers/basic_auth/DB/basic_db_auth.8 squid-3.4.2/helpers/basic_auth/DB/basic_db_auth.8
--- squid-3.4.1/helpers/basic_auth/DB/basic_db_auth.8	2013-12-09 14:42:49.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/DB/basic_db_auth.8	2013-12-31 00:51:34.000000000 +1300
@@ -124,7 +124,7 @@
 .\" ========================================================================
 .\"
 .IX Title "BASIC_DB_AUTH 1"
-.TH BASIC_DB_AUTH 1 "2013-12-08" "perl v5.10.1" "User Contributed Perl Documentation"
+.TH BASIC_DB_AUTH 1 "2013-12-30" "perl v5.10.1" "User Contributed Perl Documentation"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
diff -u -r -N squid-3.4.1/helpers/basic_auth/DB/Makefile.in squid-3.4.2/helpers/basic_auth/DB/Makefile.in
--- squid-3.4.1/helpers/basic_auth/DB/Makefile.in	2013-12-09 14:21:26.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/DB/Makefile.in	2013-12-31 00:33:50.000000000 +1300
@@ -355,7 +355,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = basic_db_auth
 man_MANS = basic_db_auth.8
diff -u -r -N squid-3.4.1/helpers/basic_auth/fake/Makefile.in squid-3.4.2/helpers/basic_auth/fake/Makefile.in
--- squid-3.4.1/helpers/basic_auth/fake/Makefile.in	2013-12-09 14:21:30.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/fake/Makefile.in	2013-12-31 00:33:52.000000000 +1300
@@ -110,7 +110,8 @@
 basic_fake_auth_OBJECTS = $(am_basic_fake_auth_OBJECTS)
 basic_fake_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 basic_fake_auth_DEPENDENCIES = $(am__DEPENDENCIES_2)
 DEFAULT_INCLUDES = 
 depcomp = $(SHELL) $(top_srcdir)/cfgaux/depcomp
@@ -353,7 +354,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 basic_fake_auth_SOURCES = fake.cc
 LDADD = $(COMPAT_LIB)
diff -u -r -N squid-3.4.1/helpers/basic_auth/getpwnam/Makefile.in squid-3.4.2/helpers/basic_auth/getpwnam/Makefile.in
--- squid-3.4.1/helpers/basic_auth/getpwnam/Makefile.in	2013-12-09 14:21:30.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/getpwnam/Makefile.in	2013-12-31 00:33:53.000000000 +1300
@@ -109,7 +109,8 @@
 am_basic_getpwnam_auth_OBJECTS = basic_getpwnam_auth.$(OBJEXT)
 basic_getpwnam_auth_OBJECTS = $(am_basic_getpwnam_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_getpwnam_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -379,7 +380,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 basic_getpwnam_auth_SOURCES = basic_getpwnam_auth.cc
 basic_getpwnam_auth_LDADD = \
diff -u -r -N squid-3.4.1/helpers/basic_auth/LDAP/Makefile.in squid-3.4.2/helpers/basic_auth/LDAP/Makefile.in
--- squid-3.4.1/helpers/basic_auth/LDAP/Makefile.in	2013-12-09 14:21:27.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/LDAP/Makefile.in	2013-12-31 00:33:50.000000000 +1300
@@ -110,7 +110,8 @@
 basic_ldap_auth_OBJECTS = $(am_basic_ldap_auth_OBJECTS)
 basic_ldap_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_ldap_auth_DEPENDENCIES = $(top_builddir)/lib/libmiscencoding.la \
 	$(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3) \
@@ -380,7 +381,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = basic_ldap_auth.8
 EXTRA_DIST = basic_ldap_auth.8 required.m4
diff -u -r -N squid-3.4.1/helpers/basic_auth/MSNT/Makefile.in squid-3.4.2/helpers/basic_auth/MSNT/Makefile.in
--- squid-3.4.1/helpers/basic_auth/MSNT/Makefile.in	2013-12-09 14:21:27.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/MSNT/Makefile.in	2013-12-31 00:33:50.000000000 +1300
@@ -113,7 +113,8 @@
 basic_msnt_auth_OBJECTS = $(am_basic_msnt_auth_OBJECTS)
 basic_msnt_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_msnt_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/smblib/libsmblib.la \
@@ -393,7 +394,7 @@
 	-I$(top_srcdir)/lib
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 MSNTAUTH_CONF = $(sysconfdir)/msntauth.conf
 basic_msnt_auth_SOURCES = \
diff -u -r -N squid-3.4.1/helpers/basic_auth/MSNT-multi-domain/Makefile.in squid-3.4.2/helpers/basic_auth/MSNT-multi-domain/Makefile.in
--- squid-3.4.1/helpers/basic_auth/MSNT-multi-domain/Makefile.in	2013-12-09 14:21:27.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/MSNT-multi-domain/Makefile.in	2013-12-31 00:33:50.000000000 +1300
@@ -352,7 +352,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = basic_msnt_multi_domain_auth
 EXTRA_DIST = basic_msnt_multi_domain_auth.pl.in README.txt required.m4
diff -u -r -N squid-3.4.1/helpers/basic_auth/NCSA/Makefile.in squid-3.4.2/helpers/basic_auth/NCSA/Makefile.in
--- squid-3.4.1/helpers/basic_auth/NCSA/Makefile.in	2013-12-09 14:21:28.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/NCSA/Makefile.in	2013-12-31 00:33:51.000000000 +1300
@@ -111,7 +111,8 @@
 basic_ncsa_auth_OBJECTS = $(am_basic_ncsa_auth_OBJECTS)
 basic_ncsa_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_ncsa_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmisccontainers.la \
@@ -392,7 +393,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 basic_ncsa_auth_SOURCES = basic_ncsa_auth.cc crypt_md5.cc crypt_md5.h
 man_MANS = basic_ncsa_auth.8
diff -u -r -N squid-3.4.1/helpers/basic_auth/NIS/Makefile.in squid-3.4.2/helpers/basic_auth/NIS/Makefile.in
--- squid-3.4.1/helpers/basic_auth/NIS/Makefile.in	2013-12-09 14:21:28.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/NIS/Makefile.in	2013-12-31 00:33:51.000000000 +1300
@@ -110,7 +110,8 @@
 	nis_support.$(OBJEXT)
 basic_nis_auth_OBJECTS = $(am_basic_nis_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_nis_auth_DEPENDENCIES = $(top_builddir)/lib/libmiscencoding.la \
 	$(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3) \
@@ -365,7 +366,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 basic_nis_auth_SOURCES = \
 	basic_nis_auth.cc \
diff -u -r -N squid-3.4.1/helpers/basic_auth/PAM/Makefile.in squid-3.4.2/helpers/basic_auth/PAM/Makefile.in
--- squid-3.4.1/helpers/basic_auth/PAM/Makefile.in	2013-12-09 14:21:28.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/PAM/Makefile.in	2013-12-31 00:33:51.000000000 +1300
@@ -109,7 +109,8 @@
 am_basic_pam_auth_OBJECTS = basic_pam_auth.$(OBJEXT)
 basic_pam_auth_OBJECTS = $(am_basic_pam_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_pam_auth_DEPENDENCIES = $(top_builddir)/lib/libmiscencoding.la \
 	$(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3)
@@ -378,7 +379,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = basic_pam_auth.8
 EXTRA_DIST = basic_pam_auth.8 required.m4
diff -u -r -N squid-3.4.1/helpers/basic_auth/POP3/Makefile.in squid-3.4.2/helpers/basic_auth/POP3/Makefile.in
--- squid-3.4.1/helpers/basic_auth/POP3/Makefile.in	2013-12-09 14:21:28.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/POP3/Makefile.in	2013-12-31 00:33:51.000000000 +1300
@@ -352,7 +352,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = basic_pop3_auth
 EXTRA_DIST = basic_pop3_auth.pl.in required.m4
diff -u -r -N squid-3.4.1/helpers/basic_auth/RADIUS/Makefile.in squid-3.4.2/helpers/basic_auth/RADIUS/Makefile.in
--- squid-3.4.1/helpers/basic_auth/RADIUS/Makefile.in	2013-12-09 14:21:29.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/RADIUS/Makefile.in	2013-12-31 00:33:52.000000000 +1300
@@ -110,7 +110,8 @@
 	radius-util.$(OBJEXT)
 basic_radius_auth_OBJECTS = $(am_basic_radius_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_radius_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -389,7 +390,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = basic_radius_auth.8
 EXTRA_DIST = basic_radius_auth.8 required.m4
diff -u -r -N squid-3.4.1/helpers/basic_auth/SASL/Makefile.in squid-3.4.2/helpers/basic_auth/SASL/Makefile.in
--- squid-3.4.1/helpers/basic_auth/SASL/Makefile.in	2013-12-09 14:21:29.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/SASL/Makefile.in	2013-12-31 00:33:52.000000000 +1300
@@ -109,7 +109,8 @@
 am_basic_sasl_auth_OBJECTS = basic_sasl_auth.$(OBJEXT)
 basic_sasl_auth_OBJECTS = $(am_basic_sasl_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_sasl_auth_DEPENDENCIES = $(top_builddir)/lib/libmiscencoding.la \
 	$(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3) \
@@ -379,7 +380,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = basic_sasl_auth.8
 basic_sasl_auth_SOURCES = basic_sasl_auth.cc
diff -u -r -N squid-3.4.1/helpers/basic_auth/SMB/Makefile.in squid-3.4.2/helpers/basic_auth/SMB/Makefile.in
--- squid-3.4.1/helpers/basic_auth/SMB/Makefile.in	2013-12-09 14:21:29.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/SMB/Makefile.in	2013-12-31 00:33:52.000000000 +1300
@@ -111,7 +111,8 @@
 am_basic_smb_auth_OBJECTS = basic_smb_auth-basic_smb_auth.$(OBJEXT)
 basic_smb_auth_OBJECTS = $(am_basic_smb_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_smb_auth_DEPENDENCIES = $(top_builddir)/lib/libmiscencoding.la \
 	$(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3)
@@ -382,7 +383,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 @ENABLE_WIN32SPECIFIC_FALSE@libexec_SCRIPTS = basic_smb_auth.sh
 basic_smb_auth_SOURCES = basic_smb_auth.cc
diff -u -r -N squid-3.4.1/helpers/basic_auth/SSPI/Makefile.in squid-3.4.2/helpers/basic_auth/SSPI/Makefile.in
--- squid-3.4.1/helpers/basic_auth/SSPI/Makefile.in	2013-12-09 14:21:29.000000000 +1300
+++ squid-3.4.2/helpers/basic_auth/SSPI/Makefile.in	2013-12-31 00:33:52.000000000 +1300
@@ -112,7 +112,8 @@
 	basic_sspi_auth-valid.$(OBJEXT)
 basic_sspi_auth_OBJECTS = $(am_basic_sspi_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 basic_sspi_auth_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -394,7 +395,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 basic_sspi_auth_SOURCES = \
 	basic_sspi_auth.cc \
diff -u -r -N squid-3.4.1/helpers/digest_auth/eDirectory/Makefile.in squid-3.4.2/helpers/digest_auth/eDirectory/Makefile.in
--- squid-3.4.1/helpers/digest_auth/eDirectory/Makefile.in	2013-12-09 14:21:30.000000000 +1300
+++ squid-3.4.2/helpers/digest_auth/eDirectory/Makefile.in	2013-12-31 00:33:53.000000000 +1300
@@ -110,7 +110,8 @@
 	ldap_backend.$(OBJEXT) edir_ldapext.$(OBJEXT)
 digest_edirectory_auth_OBJECTS = $(am_digest_edirectory_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 digest_edirectory_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -367,7 +368,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 digest_edirectory_auth_SOURCES = digest_pw_auth.cc \
 	digest_common.h \
diff -u -r -N squid-3.4.1/helpers/digest_auth/file/Makefile.in squid-3.4.2/helpers/digest_auth/file/Makefile.in
--- squid-3.4.1/helpers/digest_auth/file/Makefile.in	2013-12-09 14:21:31.000000000 +1300
+++ squid-3.4.2/helpers/digest_auth/file/Makefile.in	2013-12-31 00:33:53.000000000 +1300
@@ -111,7 +111,8 @@
 digest_file_auth_OBJECTS = $(am_digest_file_auth_OBJECTS)
 digest_file_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 digest_file_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmisccontainers.la \
@@ -392,7 +393,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = digest_file_auth.8
 digest_file_auth_SOURCES = digest_file_auth.cc \
diff -u -r -N squid-3.4.1/helpers/digest_auth/LDAP/Makefile.in squid-3.4.2/helpers/digest_auth/LDAP/Makefile.in
--- squid-3.4.1/helpers/digest_auth/LDAP/Makefile.in	2013-12-09 14:21:30.000000000 +1300
+++ squid-3.4.2/helpers/digest_auth/LDAP/Makefile.in	2013-12-31 00:33:53.000000000 +1300
@@ -110,7 +110,8 @@
 	ldap_backend.$(OBJEXT)
 digest_ldap_auth_OBJECTS = $(am_digest_ldap_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 digest_ldap_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -367,7 +368,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 digest_ldap_auth_SOURCES = digest_pw_auth.cc \
 	digest_common.h \
diff -u -r -N squid-3.4.1/helpers/external_acl/AD_group/Makefile.in squid-3.4.2/helpers/external_acl/AD_group/Makefile.in
--- squid-3.4.1/helpers/external_acl/AD_group/Makefile.in	2013-12-09 14:21:31.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/AD_group/Makefile.in	2013-12-31 00:33:54.000000000 +1300
@@ -110,7 +110,8 @@
 ext_ad_group_acl_OBJECTS = $(am_ext_ad_group_acl_OBJECTS)
 ext_ad_group_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_ad_group_acl_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -379,7 +380,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ext_ad_group_acl_SOURCES = ext_ad_group_acl.cc
 man_MANS = ext_ad_group_acl.8
diff -u -r -N squid-3.4.1/helpers/external_acl/eDirectory_userip/Makefile.in squid-3.4.2/helpers/external_acl/eDirectory_userip/Makefile.in
--- squid-3.4.1/helpers/external_acl/eDirectory_userip/Makefile.in	2013-12-09 14:21:33.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/eDirectory_userip/Makefile.in	2013-12-31 00:33:54.000000000 +1300
@@ -111,7 +111,8 @@
 ext_edirectory_userip_acl_OBJECTS =  \
 	$(am_ext_edirectory_userip_acl_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_edirectory_userip_acl_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3) $(am__DEPENDENCIES_3) \
@@ -381,7 +382,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ext_edirectory_userip_acl_SOURCES = \
 	ext_edirectory_userip_acl.cc
diff -u -r -N squid-3.4.1/helpers/external_acl/file_userip/Makefile.in squid-3.4.2/helpers/external_acl/file_userip/Makefile.in
--- squid-3.4.1/helpers/external_acl/file_userip/Makefile.in	2013-12-09 14:21:33.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/file_userip/Makefile.in	2013-12-31 00:33:55.000000000 +1300
@@ -110,7 +110,8 @@
 ext_file_userip_acl_OBJECTS = $(am_ext_file_userip_acl_OBJECTS)
 ext_file_userip_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_file_userip_acl_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -380,7 +381,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ext_file_userip_acl_SOURCES = ext_file_userip_acl.cc
 man_MANS = ext_file_userip_acl.8
diff -u -r -N squid-3.4.1/helpers/external_acl/kerberos_ldap_group/Makefile.in squid-3.4.2/helpers/external_acl/kerberos_ldap_group/Makefile.in
--- squid-3.4.1/helpers/external_acl/kerberos_ldap_group/Makefile.in	2013-12-09 14:21:33.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/kerberos_ldap_group/Makefile.in	2013-12-31 00:33:55.000000000 +1300
@@ -116,7 +116,8 @@
 ext_kerberos_ldap_group_acl_OBJECTS =  \
 	$(am_ext_kerberos_ldap_group_acl_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_kerberos_ldap_group_acl_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -437,7 +438,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 EXTRA_DIST = README required.m4 cert_tool ext_kerberos_ldap_group_acl.8
 SUBDIRS = 
diff -u -r -N squid-3.4.1/helpers/external_acl/LDAP_group/Makefile.in squid-3.4.2/helpers/external_acl/LDAP_group/Makefile.in
--- squid-3.4.1/helpers/external_acl/LDAP_group/Makefile.in	2013-12-09 14:21:32.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/LDAP_group/Makefile.in	2013-12-31 00:33:54.000000000 +1300
@@ -110,7 +110,8 @@
 ext_ldap_group_acl_OBJECTS = $(am_ext_ldap_group_acl_OBJECTS)
 ext_ldap_group_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_ldap_group_acl_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -381,7 +382,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ext_ldap_group_acl_SOURCES = ext_ldap_group_acl.cc
 man_MANS = ext_ldap_group_acl.8
diff -u -r -N squid-3.4.1/helpers/external_acl/LM_group/Makefile.in squid-3.4.2/helpers/external_acl/LM_group/Makefile.in
--- squid-3.4.1/helpers/external_acl/LM_group/Makefile.in	2013-12-09 14:21:32.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/LM_group/Makefile.in	2013-12-31 00:33:54.000000000 +1300
@@ -110,7 +110,8 @@
 ext_lm_group_acl_OBJECTS = $(am_ext_lm_group_acl_OBJECTS)
 ext_lm_group_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_lm_group_acl_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -379,7 +380,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ext_lm_group_acl_SOURCES = ext_lm_group_acl.cc
 LDADD = \
diff -u -r -N squid-3.4.1/helpers/external_acl/session/Makefile.in squid-3.4.2/helpers/external_acl/session/Makefile.in
--- squid-3.4.1/helpers/external_acl/session/Makefile.in	2013-12-09 14:21:33.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/session/Makefile.in	2013-12-31 00:33:55.000000000 +1300
@@ -110,7 +110,8 @@
 ext_session_acl_OBJECTS = $(am_ext_session_acl_OBJECTS)
 ext_session_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_session_acl_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -379,7 +380,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = ext_session_acl.8
 EXTRA_DIST = ext_session_acl.8 required.m4
diff -u -r -N squid-3.4.1/helpers/external_acl/SQL_session/ext_sql_session_acl.8 squid-3.4.2/helpers/external_acl/SQL_session/ext_sql_session_acl.8
--- squid-3.4.1/helpers/external_acl/SQL_session/ext_sql_session_acl.8	2013-12-09 14:42:50.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/SQL_session/ext_sql_session_acl.8	2013-12-31 00:51:37.000000000 +1300
@@ -124,7 +124,7 @@
 .\" ========================================================================
 .\"
 .IX Title "EXT_SQL_SESSION_ACL 1"
-.TH EXT_SQL_SESSION_ACL 1 "2013-12-08" "perl v5.10.1" "User Contributed Perl Documentation"
+.TH EXT_SQL_SESSION_ACL 1 "2013-12-30" "perl v5.10.1" "User Contributed Perl Documentation"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
diff -u -r -N squid-3.4.1/helpers/external_acl/SQL_session/Makefile.in squid-3.4.2/helpers/external_acl/SQL_session/Makefile.in
--- squid-3.4.1/helpers/external_acl/SQL_session/Makefile.in	2013-12-09 14:21:32.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/SQL_session/Makefile.in	2013-12-31 00:33:54.000000000 +1300
@@ -355,7 +355,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = ext_sql_session_acl
 man_MANS = ext_sql_session_acl.8
diff -u -r -N squid-3.4.1/helpers/external_acl/time_quota/Makefile.in squid-3.4.2/helpers/external_acl/time_quota/Makefile.in
--- squid-3.4.1/helpers/external_acl/time_quota/Makefile.in	2013-12-09 14:21:34.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/time_quota/Makefile.in	2013-12-31 00:33:55.000000000 +1300
@@ -110,7 +110,8 @@
 ext_time_quota_acl_OBJECTS = $(am_ext_time_quota_acl_OBJECTS)
 ext_time_quota_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_time_quota_acl_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -380,7 +381,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = ext_time_quota_acl.8
 EXTRA_DIST = ext_time_quota_acl.8 required.m4
diff -u -r -N squid-3.4.1/helpers/external_acl/unix_group/Makefile.in squid-3.4.2/helpers/external_acl/unix_group/Makefile.in
--- squid-3.4.1/helpers/external_acl/unix_group/Makefile.in	2013-12-09 14:21:34.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/unix_group/Makefile.in	2013-12-31 00:33:56.000000000 +1300
@@ -110,7 +110,8 @@
 ext_unix_group_acl_OBJECTS = $(am_ext_unix_group_acl_OBJECTS)
 ext_unix_group_acl_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ext_unix_group_acl_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -380,7 +381,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = ext_unix_group_acl.8
 EXTRA_DIST = ext_unix_group_acl.8 required.m4
diff -u -r -N squid-3.4.1/helpers/external_acl/wbinfo_group/ext_wbinfo_group_acl.8 squid-3.4.2/helpers/external_acl/wbinfo_group/ext_wbinfo_group_acl.8
--- squid-3.4.1/helpers/external_acl/wbinfo_group/ext_wbinfo_group_acl.8	2013-12-09 14:42:51.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/wbinfo_group/ext_wbinfo_group_acl.8	2013-12-31 00:51:38.000000000 +1300
@@ -124,7 +124,7 @@
 .\" ========================================================================
 .\"
 .IX Title "EXT_WBINFO_GROUP_ACL.PL.IN 1"
-.TH EXT_WBINFO_GROUP_ACL.PL.IN 1 "2013-12-08" "perl v5.10.1" "User Contributed Perl Documentation"
+.TH EXT_WBINFO_GROUP_ACL.PL.IN 1 "2013-12-30" "perl v5.10.1" "User Contributed Perl Documentation"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
diff -u -r -N squid-3.4.1/helpers/external_acl/wbinfo_group/Makefile.in squid-3.4.2/helpers/external_acl/wbinfo_group/Makefile.in
--- squid-3.4.1/helpers/external_acl/wbinfo_group/Makefile.in	2013-12-09 14:21:34.000000000 +1300
+++ squid-3.4.2/helpers/external_acl/wbinfo_group/Makefile.in	2013-12-31 00:33:56.000000000 +1300
@@ -355,7 +355,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = ext_wbinfo_group_acl
 EXTRA_DIST = ext_wbinfo_group_acl.pl.in required.m4 \
diff -u -r -N squid-3.4.1/helpers/log_daemon/DB/log_db_daemon.8 squid-3.4.2/helpers/log_daemon/DB/log_db_daemon.8
--- squid-3.4.1/helpers/log_daemon/DB/log_db_daemon.8	2013-12-09 14:42:51.000000000 +1300
+++ squid-3.4.2/helpers/log_daemon/DB/log_db_daemon.8	2013-12-31 00:51:38.000000000 +1300
@@ -124,7 +124,7 @@
 .\" ========================================================================
 .\"
 .IX Title "LOG_DB_DAEMON 1"
-.TH LOG_DB_DAEMON 1 "2013-12-08" "perl v5.10.1" "User Contributed Perl Documentation"
+.TH LOG_DB_DAEMON 1 "2013-12-30" "perl v5.10.1" "User Contributed Perl Documentation"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
diff -u -r -N squid-3.4.1/helpers/log_daemon/DB/Makefile.in squid-3.4.2/helpers/log_daemon/DB/Makefile.in
--- squid-3.4.1/helpers/log_daemon/DB/Makefile.in	2013-12-09 14:21:34.000000000 +1300
+++ squid-3.4.2/helpers/log_daemon/DB/Makefile.in	2013-12-31 00:33:56.000000000 +1300
@@ -355,7 +355,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = log_db_daemon
 man_MANS = log_db_daemon.8
diff -u -r -N squid-3.4.1/helpers/log_daemon/file/Makefile.in squid-3.4.2/helpers/log_daemon/file/Makefile.in
--- squid-3.4.1/helpers/log_daemon/file/Makefile.in	2013-12-09 14:21:35.000000000 +1300
+++ squid-3.4.2/helpers/log_daemon/file/Makefile.in	2013-12-31 00:33:56.000000000 +1300
@@ -109,7 +109,8 @@
 am_log_file_daemon_OBJECTS = log_file_daemon.$(OBJEXT)
 log_file_daemon_OBJECTS = $(am_log_file_daemon_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 log_file_daemon_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -354,7 +355,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 log_file_daemon_SOURCES = log_file_daemon.cc
 log_file_daemon_LDADD = \
diff -u -r -N squid-3.4.1/helpers/negotiate_auth/kerberos/Makefile.in squid-3.4.2/helpers/negotiate_auth/kerberos/Makefile.in
--- squid-3.4.1/helpers/negotiate_auth/kerberos/Makefile.in	2013-12-09 14:21:36.000000000 +1300
+++ squid-3.4.2/helpers/negotiate_auth/kerberos/Makefile.in	2013-12-31 00:33:57.000000000 +1300
@@ -113,7 +113,8 @@
 negotiate_kerberos_auth_OBJECTS =  \
 	$(am_negotiate_kerberos_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 negotiate_kerberos_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -447,7 +448,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 EXTRA_DIST = README COPYING required.m4 negotiate_kerberos_auth.8
 SUBDIRS = 
diff -u -r -N squid-3.4.1/helpers/negotiate_auth/SSPI/Makefile.in squid-3.4.2/helpers/negotiate_auth/SSPI/Makefile.in
--- squid-3.4.1/helpers/negotiate_auth/SSPI/Makefile.in	2013-12-09 14:21:35.000000000 +1300
+++ squid-3.4.2/helpers/negotiate_auth/SSPI/Makefile.in	2013-12-31 00:33:56.000000000 +1300
@@ -110,7 +110,8 @@
 negotiate_sspi_auth_OBJECTS = $(am_negotiate_sspi_auth_OBJECTS)
 negotiate_sspi_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 negotiate_sspi_auth_DEPENDENCIES = $(am__DEPENDENCIES_2) \
 	$(am__DEPENDENCIES_3)
@@ -355,7 +356,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 negotiate_sspi_auth_SOURCES = negotiate_sspi_auth.cc
 LDADD = \
diff -u -r -N squid-3.4.1/helpers/negotiate_auth/wrapper/Makefile.in squid-3.4.2/helpers/negotiate_auth/wrapper/Makefile.in
--- squid-3.4.1/helpers/negotiate_auth/wrapper/Makefile.in	2013-12-09 14:21:36.000000000 +1300
+++ squid-3.4.2/helpers/negotiate_auth/wrapper/Makefile.in	2013-12-31 00:33:57.000000000 +1300
@@ -109,7 +109,8 @@
 am_negotiate_wrapper_auth_OBJECTS = negotiate_wrapper.$(OBJEXT)
 negotiate_wrapper_auth_OBJECTS = $(am_negotiate_wrapper_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 negotiate_wrapper_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmiscencoding.la $(am__DEPENDENCIES_2) \
@@ -355,7 +356,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 EXTRA_DIST = required.m4
 negotiate_wrapper_auth_SOURCES = negotiate_wrapper.cc
diff -u -r -N squid-3.4.1/helpers/ntlm_auth/fake/Makefile.in squid-3.4.2/helpers/ntlm_auth/fake/Makefile.in
--- squid-3.4.1/helpers/ntlm_auth/fake/Makefile.in	2013-12-09 14:21:37.000000000 +1300
+++ squid-3.4.2/helpers/ntlm_auth/fake/Makefile.in	2013-12-31 00:33:57.000000000 +1300
@@ -109,7 +109,8 @@
 am_ntlm_fake_auth_OBJECTS = ntlm_fake_auth.$(OBJEXT)
 ntlm_fake_auth_OBJECTS = $(am_ntlm_fake_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ntlm_fake_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/ntlmauth/libntlmauth.la \
@@ -357,7 +358,7 @@
 	-I$(top_srcdir)/lib
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ntlm_fake_auth_SOURCES = ntlm_fake_auth.cc
 ntlm_fake_auth_LDADD = \
diff -u -r -N squid-3.4.1/helpers/ntlm_auth/smb_lm/Makefile.in squid-3.4.2/helpers/ntlm_auth/smb_lm/Makefile.in
--- squid-3.4.1/helpers/ntlm_auth/smb_lm/Makefile.in	2013-12-09 14:21:37.000000000 +1300
+++ squid-3.4.2/helpers/ntlm_auth/smb_lm/Makefile.in	2013-12-31 00:33:58.000000000 +1300
@@ -109,7 +109,8 @@
 am_ntlm_smb_lm_auth_OBJECTS = ntlm_smb_lm_auth.$(OBJEXT)
 ntlm_smb_lm_auth_OBJECTS = $(am_ntlm_smb_lm_auth_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ntlm_smb_lm_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/smblib/libsmblib.la \
@@ -359,7 +360,7 @@
 	-I$(top_srcdir)/lib
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 ntlm_smb_lm_auth_SOURCES = ntlm_smb_lm_auth.cc
 ntlm_smb_lm_auth_LDADD = \
diff -u -r -N squid-3.4.1/helpers/ntlm_auth/SSPI/Makefile.in squid-3.4.2/helpers/ntlm_auth/SSPI/Makefile.in
--- squid-3.4.1/helpers/ntlm_auth/SSPI/Makefile.in	2013-12-09 14:21:36.000000000 +1300
+++ squid-3.4.2/helpers/ntlm_auth/SSPI/Makefile.in	2013-12-31 00:33:57.000000000 +1300
@@ -110,7 +110,8 @@
 ntlm_sspi_auth_OBJECTS = $(am_ntlm_sspi_auth_OBJECTS)
 ntlm_sspi_auth_LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 ntlm_sspi_auth_DEPENDENCIES =  \
 	$(top_builddir)/lib/ntlmauth/libntlmauth.la \
@@ -380,7 +381,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 man_MANS = ntlm_sspi_auth.8
 ntlm_sspi_auth_SOURCES = ntlm_sspi_auth.cc
diff -u -r -N squid-3.4.1/helpers/ssl/Makefile.in squid-3.4.2/helpers/ssl/Makefile.in
--- squid-3.4.1/helpers/ssl/Makefile.in	2013-12-09 14:21:37.000000000 +1300
+++ squid-3.4.2/helpers/ssl/Makefile.in	2013-12-31 00:33:58.000000000 +1300
@@ -352,7 +352,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = cert_valid.pl
 EXTRA_DIST = \
diff -u -r -N squid-3.4.1/helpers/storeid_rewrite/file/Makefile.in squid-3.4.2/helpers/storeid_rewrite/file/Makefile.in
--- squid-3.4.1/helpers/storeid_rewrite/file/Makefile.in	2013-12-09 14:21:37.000000000 +1300
+++ squid-3.4.2/helpers/storeid_rewrite/file/Makefile.in	2013-12-31 00:33:58.000000000 +1300
@@ -355,7 +355,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 libexec_SCRIPTS = storeid_file_rewrite
 man_MANS = storeid_file_rewrite.8
diff -u -r -N squid-3.4.1/helpers/storeid_rewrite/file/storeid_file_rewrite.8 squid-3.4.2/helpers/storeid_rewrite/file/storeid_file_rewrite.8
--- squid-3.4.1/helpers/storeid_rewrite/file/storeid_file_rewrite.8	2013-12-09 14:42:52.000000000 +1300
+++ squid-3.4.2/helpers/storeid_rewrite/file/storeid_file_rewrite.8	2013-12-31 00:51:41.000000000 +1300
@@ -124,7 +124,7 @@
 .\" ========================================================================
 .\"
 .IX Title "STOREID_FILE_REWRITE 1"
-.TH STOREID_FILE_REWRITE 1 "2013-12-08" "perl v5.10.1" "User Contributed Perl Documentation"
+.TH STOREID_FILE_REWRITE 1 "2013-12-30" "perl v5.10.1" "User Contributed Perl Documentation"
 .\" For nroff, turn off justification.  Always turn off hyphenation; it makes
 .\" way too many mistakes in technical documents.
 .if n .ad l
diff -u -r -N squid-3.4.1/helpers/url_rewrite/fake/Makefile.in squid-3.4.2/helpers/url_rewrite/fake/Makefile.in
--- squid-3.4.1/helpers/url_rewrite/fake/Makefile.in	2013-12-09 14:21:38.000000000 +1300
+++ squid-3.4.2/helpers/url_rewrite/fake/Makefile.in	2013-12-31 00:33:58.000000000 +1300
@@ -110,7 +110,8 @@
 am_url_fake_rewrite_OBJECTS = fake.$(OBJEXT)
 url_fake_rewrite_OBJECTS = $(am_url_fake_rewrite_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 url_fake_rewrite_DEPENDENCIES = $(am__DEPENDENCIES_2)
 am__vpath_adj_setup = srcdirstrip=`echo "$(srcdir)" | sed 's|.|.|g'`;
 am__vpath_adj = case $$p in \
@@ -375,7 +376,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 url_fake_rewrite_SOURCES = fake.cc
 url_fake_rewrite_LDADD = $(COMPAT_LIB)
diff -u -r -N squid-3.4.1/include/version.h squid-3.4.2/include/version.h
--- squid-3.4.1/include/version.h	2013-12-09 14:22:01.000000000 +1300
+++ squid-3.4.2/include/version.h	2013-12-31 00:34:14.000000000 +1300
@@ -7,7 +7,7 @@
  */
 
 #ifndef SQUID_RELEASE_TIME
-#define SQUID_RELEASE_TIME 1386552053
+#define SQUID_RELEASE_TIME 1388403205
 #endif
 
 #ifndef APP_SHORTNAME
diff -u -r -N squid-3.4.1/lib/libTrie/Makefile.in squid-3.4.2/lib/libTrie/Makefile.in
--- squid-3.4.1/lib/libTrie/Makefile.in	2013-12-09 14:21:39.000000000 +1300
+++ squid-3.4.2/lib/libTrie/Makefile.in	2013-12-31 00:33:59.000000000 +1300
@@ -400,7 +400,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 DIST_SUBDIRS = test
 SUBDIRS = test
diff -u -r -N squid-3.4.1/lib/libTrie/test/Makefile.in squid-3.4.2/lib/libTrie/test/Makefile.in
--- squid-3.4.1/lib/libTrie/test/Makefile.in	2013-12-09 14:21:39.000000000 +1300
+++ squid-3.4.2/lib/libTrie/test/Makefile.in	2013-12-31 00:33:59.000000000 +1300
@@ -347,7 +347,7 @@
 	-I$(top_srcdir)/include
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 trie_SOURCES = trie.cc
 trie_LDADD = $(top_builddir)/lib/libTrie/libTrie.a
diff -u -r -N squid-3.4.1/lib/Makefile.in squid-3.4.2/lib/Makefile.in
--- squid-3.4.1/lib/Makefile.in	2013-12-09 14:21:39.000000000 +1300
+++ squid-3.4.2/lib/Makefile.in	2013-12-31 00:33:59.000000000 +1300
@@ -138,7 +138,8 @@
 tests_testAll_OBJECTS = $(am_tests_testAll_OBJECTS)
 am__DEPENDENCIES_1 =
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_2 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_3 = $(am__DEPENDENCIES_2)
+am__DEPENDENCIES_3 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_2)
 tests_testAll_DEPENDENCIES = $(am__DEPENDENCIES_1) \
 	$(am__DEPENDENCIES_1) $(top_builddir)/lib/libmiscencoding.la \
 	$(top_builddir)/lib/libmiscutil.la $(am__DEPENDENCIES_3)
@@ -439,7 +440,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 DIST_SUBDIRS = ntlmauth profiler rfcnb smblib libTrie
 SUBDIRS = $(am__append_2) $(am__append_3) $(am__append_5) \
diff -u -r -N squid-3.4.1/lib/ntlmauth/Makefile.in squid-3.4.2/lib/ntlmauth/Makefile.in
--- squid-3.4.1/lib/ntlmauth/Makefile.in	2013-12-09 14:21:40.000000000 +1300
+++ squid-3.4.2/lib/ntlmauth/Makefile.in	2013-12-31 00:33:59.000000000 +1300
@@ -358,7 +358,7 @@
 	-I$(top_srcdir)/lib
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libntlmauth.la
 libntlmauth_la_SOURCES = \
diff -u -r -N squid-3.4.1/lib/profiler/Makefile.in squid-3.4.2/lib/profiler/Makefile.in
--- squid-3.4.1/lib/profiler/Makefile.in	2013-12-09 14:21:40.000000000 +1300
+++ squid-3.4.2/lib/profiler/Makefile.in	2013-12-31 00:34:00.000000000 +1300
@@ -361,7 +361,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 XPROFSRC = \
 	get_tick.h \
diff -u -r -N squid-3.4.1/lib/rfcnb/Makefile.in squid-3.4.2/lib/rfcnb/Makefile.in
--- squid-3.4.1/lib/rfcnb/Makefile.in	2013-12-09 14:21:40.000000000 +1300
+++ squid-3.4.2/lib/rfcnb/Makefile.in	2013-12-31 00:34:00.000000000 +1300
@@ -349,7 +349,7 @@
 	-I$(top_srcdir)/lib
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = librfcnb.la
 librfcnb_la_SOURCES = \
diff -u -r -N squid-3.4.1/lib/smblib/Makefile.in squid-3.4.2/lib/smblib/Makefile.in
--- squid-3.4.1/lib/smblib/Makefile.in	2013-12-09 14:21:41.000000000 +1300
+++ squid-3.4.2/lib/smblib/Makefile.in	2013-12-31 00:34:00.000000000 +1300
@@ -350,7 +350,7 @@
 	-I$(top_srcdir)/lib
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libsmblib.la
 libsmblib_la_SOURCES = \
diff -u -r -N squid-3.4.1/RELEASENOTES.html squid-3.4.2/RELEASENOTES.html
--- squid-3.4.1/RELEASENOTES.html	2013-12-09 14:42:57.000000000 +1300
+++ squid-3.4.2/RELEASENOTES.html	2013-12-31 00:51:58.000000000 +1300
@@ -2,10 +2,10 @@
 <HTML>
 <HEAD>
  <META NAME="GENERATOR" CONTENT="LinuxDoc-Tools 0.9.69">
- <TITLE>Squid 3.4.0.3 release notes</TITLE>
+ <TITLE>Squid 3.4.2 release notes</TITLE>
 </HEAD>
 <BODY>
-<H1>Squid 3.4.0.3 release notes</H1>
+<H1>Squid 3.4.2 release notes</H1>
 
 <H2>Squid Developers</H2>
 <HR>
@@ -57,7 +57,7 @@
 <HR>
 <H2><A NAME="s1">1.</A> <A HREF="#toc1">Notice</A></H2>
 
-<P>The Squid Team are pleased to announce the release of Squid-3.4.0.3 for testing.</P>
+<P>The Squid Team are pleased to announce the release of Squid-3.4.2 for testing.</P>
 <P>This new release is available for download from 
 <A HREF="http://www.squid-cache.org/Versions/v3/3.4/">http://www.squid-cache.org/Versions/v3/3.4/</A> or the
 <A HREF="http://www.squid-cache.org/Mirrors/http-mirrors.html">mirrors</A>.</P>
@@ -273,7 +273,7 @@
 </PRE>
 </P>
 
-<P>There hasve also been changes to individual directives in the config file.</P>
+<P>There have also been changes to individual directives in the config file.</P>
 <P>This section gives a thorough account of those changes in three categories:</P>
 <P>
 <UL>
diff -u -r -N squid-3.4.1/snmplib/Makefile.am squid-3.4.2/snmplib/Makefile.am
--- squid-3.4.1/snmplib/Makefile.am	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/snmplib/Makefile.am	2013-12-31 00:33:27.000000000 +1300
@@ -4,8 +4,8 @@
 ## 
 AM_CFLAGS = $(SQUID_CFLAGS)
 AM_CXXFLAGS = $(SQUID_CXXFLAGS)
-noinst_LIBRARIES = libsnmplib.a
-libsnmplib_a_SOURCES  = asn1.c parse.c snmp_vars.c \
+noinst_LTLIBRARIES = libsnmplib.la
+libsnmplib_la_SOURCES  = asn1.c parse.c snmp_vars.c \
 	coexistance.c snmp_api.c snmp_error.c  \
 	mib.c snmp_api_error.c   \
 	snmp_msg.c \
diff -u -r -N squid-3.4.1/snmplib/Makefile.in squid-3.4.2/snmplib/Makefile.in
--- squid-3.4.1/snmplib/Makefile.in	2013-12-09 14:21:41.000000000 +1300
+++ squid-3.4.2/snmplib/Makefile.in	2013-12-31 00:34:00.000000000 +1300
@@ -99,15 +99,12 @@
 CONFIG_HEADER = $(top_builddir)/include/autoconf.h
 CONFIG_CLEAN_FILES =
 CONFIG_CLEAN_VPATH_FILES =
-LIBRARIES = $(noinst_LIBRARIES)
-ARFLAGS = cru
-libsnmplib_a_AR = $(AR) $(ARFLAGS)
-libsnmplib_a_LIBADD =
-am_libsnmplib_a_OBJECTS = asn1.$(OBJEXT) parse.$(OBJEXT) \
-	snmp_vars.$(OBJEXT) coexistance.$(OBJEXT) snmp_api.$(OBJEXT) \
-	snmp_error.$(OBJEXT) mib.$(OBJEXT) snmp_api_error.$(OBJEXT) \
-	snmp_msg.$(OBJEXT) snmp_pdu.$(OBJEXT) snmplib_debug.$(OBJEXT)
-libsnmplib_a_OBJECTS = $(am_libsnmplib_a_OBJECTS)
+LTLIBRARIES = $(noinst_LTLIBRARIES)
+libsnmplib_la_LIBADD =
+am_libsnmplib_la_OBJECTS = asn1.lo parse.lo snmp_vars.lo \
+	coexistance.lo snmp_api.lo snmp_error.lo mib.lo \
+	snmp_api_error.lo snmp_msg.lo snmp_pdu.lo snmplib_debug.lo
+libsnmplib_la_OBJECTS = $(am_libsnmplib_la_OBJECTS)
 DEFAULT_INCLUDES = 
 depcomp = $(SHELL) $(top_srcdir)/cfgaux/depcomp
 am__depfiles_maybe = depfiles
@@ -121,8 +118,8 @@
 LINK = $(LIBTOOL) --tag=CC $(AM_LIBTOOLFLAGS) $(LIBTOOLFLAGS) \
 	--mode=link $(CCLD) $(AM_CFLAGS) $(CFLAGS) $(AM_LDFLAGS) \
 	$(LDFLAGS) -o $@
-SOURCES = $(libsnmplib_a_SOURCES)
-DIST_SOURCES = $(libsnmplib_a_SOURCES)
+SOURCES = $(libsnmplib_la_SOURCES)
+DIST_SOURCES = $(libsnmplib_la_SOURCES)
 ETAGS = etags
 CTAGS = ctags
 DISTFILES = $(DIST_COMMON) $(DIST_SOURCES) $(TEXINFOS) $(EXTRA_DIST)
@@ -341,8 +338,8 @@
 top_srcdir = @top_srcdir@
 AM_CFLAGS = $(SQUID_CFLAGS)
 AM_CXXFLAGS = $(SQUID_CXXFLAGS)
-noinst_LIBRARIES = libsnmplib.a
-libsnmplib_a_SOURCES = asn1.c parse.c snmp_vars.c \
+noinst_LTLIBRARIES = libsnmplib.la
+libsnmplib_la_SOURCES = asn1.c parse.c snmp_vars.c \
 	coexistance.c snmp_api.c snmp_error.c  \
 	mib.c snmp_api_error.c   \
 	snmp_msg.c \
@@ -388,12 +385,16 @@
 	cd $(top_builddir) && $(MAKE) $(AM_MAKEFLAGS) am--refresh
 $(am__aclocal_m4_deps):
 
-clean-noinstLIBRARIES:
-	-test -z "$(noinst_LIBRARIES)" || rm -f $(noinst_LIBRARIES)
-libsnmplib.a: $(libsnmplib_a_OBJECTS) $(libsnmplib_a_DEPENDENCIES) 
-	-rm -f libsnmplib.a
-	$(libsnmplib_a_AR) libsnmplib.a $(libsnmplib_a_OBJECTS) $(libsnmplib_a_LIBADD)
-	$(RANLIB) libsnmplib.a
+clean-noinstLTLIBRARIES:
+	-test -z "$(noinst_LTLIBRARIES)" || rm -f $(noinst_LTLIBRARIES)
+	@list='$(noinst_LTLIBRARIES)'; for p in $$list; do \
+	  dir="`echo $$p | sed -e 's|/[^/]*$$||'`"; \
+	  test "$$dir" != "$$p" || dir=.; \
+	  echo "rm -f \"$${dir}/so_locations\""; \
+	  rm -f "$${dir}/so_locations"; \
+	done
+libsnmplib.la: $(libsnmplib_la_OBJECTS) $(libsnmplib_la_DEPENDENCIES) 
+	$(LINK)  $(libsnmplib_la_OBJECTS) $(libsnmplib_la_LIBADD) $(LIBS)
 
 mostlyclean-compile:
 	-rm -f *.$(OBJEXT)
@@ -401,17 +402,17 @@
 distclean-compile:
 	-rm -f *.tab.c
 
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/asn1.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/coexistance.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mib.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/parse.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_api.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_api_error.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_error.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_msg.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_pdu.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_vars.Po@am__quote@
-@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmplib_debug.Po@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/asn1.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/coexistance.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/mib.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/parse.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_api.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_api_error.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_error.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_msg.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_pdu.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmp_vars.Plo@am__quote@
+@AMDEP_TRUE@@am__include@ @am__quote@./$(DEPDIR)/snmplib_debug.Plo@am__quote@
 
 .c.o:
 @am__fastdepCC_TRUE@	$(COMPILE) -MT $@ -MD -MP -MF $(DEPDIR)/$*.Tpo -c -o $@ $<
@@ -524,7 +525,7 @@
 	done
 check-am: all-am
 check: check-am
-all-am: Makefile $(LIBRARIES)
+all-am: Makefile $(LTLIBRARIES)
 installdirs:
 install: install-am
 install-exec: install-exec-am
@@ -553,7 +554,7 @@
 	@echo "it deletes files that may require special tools to rebuild."
 clean: clean-am
 
-clean-am: clean-generic clean-libtool clean-noinstLIBRARIES \
+clean-am: clean-generic clean-libtool clean-noinstLTLIBRARIES \
 	mostlyclean-am
 
 distclean: distclean-am
@@ -625,7 +626,7 @@
 .MAKE: install-am install-strip
 
 .PHONY: CTAGS GTAGS all all-am check check-am clean clean-generic \
-	clean-libtool clean-noinstLIBRARIES ctags distclean \
+	clean-libtool clean-noinstLTLIBRARIES ctags distclean \
 	distclean-compile distclean-generic distclean-libtool \
 	distclean-tags distdir dvi dvi-am html html-am info info-am \
 	install install-am install-data install-data-am install-dvi \
diff -u -r -N squid-3.4.1/src/acl/Acl.h squid-3.4.2/src/acl/Acl.h
--- squid-3.4.1/src/acl/Acl.h	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/acl/Acl.h	2013-12-31 00:33:27.000000000 +1300
@@ -53,6 +53,7 @@
 // ACLData Flags
 #define ACL_F_REGEX_CASE 'i'
 #define ACL_F_NO_LOOKUP 'n'
+#define ACL_F_STRICT 's'
 #define ACL_F_END '\0'
 
 /**
diff -u -r -N squid-3.4.1/src/acl/Makefile.in squid-3.4.2/src/acl/Makefile.in
--- squid-3.4.1/src/acl/Makefile.in	2013-12-09 14:21:44.000000000 +1300
+++ squid-3.4.2/src/acl/Makefile.in	2013-12-31 00:34:02.000000000 +1300
@@ -409,7 +409,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libapi.la libstate.la libacls.la
 libapi_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/adaptation/ecap/Makefile.in squid-3.4.2/src/adaptation/ecap/Makefile.in
--- squid-3.4.1/src/adaptation/ecap/Makefile.in	2013-12-09 14:21:44.000000000 +1300
+++ squid-3.4.2/src/adaptation/ecap/Makefile.in	2013-12-31 00:34:03.000000000 +1300
@@ -364,7 +364,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libsquid-ecap.la
 libsquid_ecap_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/adaptation/icap/Makefile.in squid-3.4.2/src/adaptation/icap/Makefile.in
--- squid-3.4.1/src/adaptation/icap/Makefile.in	2013-12-09 14:21:45.000000000 +1300
+++ squid-3.4.2/src/adaptation/icap/Makefile.in	2013-12-31 00:34:03.000000000 +1300
@@ -359,7 +359,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libicap.la
 libicap_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/adaptation/Makefile.in squid-3.4.2/src/adaptation/Makefile.in
--- squid-3.4.1/src/adaptation/Makefile.in	2013-12-09 14:21:44.000000000 +1300
+++ squid-3.4.2/src/adaptation/Makefile.in	2013-12-31 00:34:03.000000000 +1300
@@ -400,7 +400,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 SUBDIRS = $(am__append_2) $(am__append_3)
 noinst_LTLIBRARIES = libadaptation.la
diff -u -r -N squid-3.4.1/src/anyp/Makefile.in squid-3.4.2/src/anyp/Makefile.in
--- squid-3.4.1/src/anyp/Makefile.in	2013-12-09 14:21:45.000000000 +1300
+++ squid-3.4.2/src/anyp/Makefile.in	2013-12-31 00:34:03.000000000 +1300
@@ -357,7 +357,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libanyp.la
 libanyp_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/auth/AclMaxUserIp.cc squid-3.4.2/src/auth/AclMaxUserIp.cc
--- squid-3.4.1/src/auth/AclMaxUserIp.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/auth/AclMaxUserIp.cc	2013-12-31 00:33:27.000000000 +1300
@@ -13,17 +13,22 @@
 #include "ConfigParser.h"
 #include "Parsing.h"
 
+ACLFlag
+ACLMaxUserIP::SupportedFlags[] = {ACL_F_STRICT, ACL_F_END};
+
 ACL *
 ACLMaxUserIP::clone() const
 {
     return new ACLMaxUserIP(*this);
 }
 
-ACLMaxUserIP::ACLMaxUserIP (char const *theClass) : class_ (theClass), maximum(0)
+ACLMaxUserIP::ACLMaxUserIP (char const *theClass) : ACL(SupportedFlags), class_ (theClass), maximum(0)
 {}
 
-ACLMaxUserIP::ACLMaxUserIP (ACLMaxUserIP const & old) :class_ (old.class_), maximum (old.maximum), flags (old.flags)
-{}
+ACLMaxUserIP::ACLMaxUserIP (ACLMaxUserIP const & old) : class_ (old.class_), maximum (old.maximum)
+{
+   flags = old.flags;
+}
 
 ACLMaxUserIP::~ACLMaxUserIP()
 {}
@@ -61,15 +66,6 @@
 
     debugs(28, 5, "aclParseUserMaxIP: First token is " << t);
 
-    if (strcmp("-s", t) == 0) {
-        debugs(28, 5, "aclParseUserMaxIP: Going strict");
-        flags.strict = true;
-        t = ConfigParser::strtokFile();
-    }
-
-    if (!t)
-        return;
-
     maximum = xatoi(t);
 
     debugs(28, 5, "aclParseUserMaxIP: Max IP address's " << maximum);
@@ -97,7 +93,7 @@
     debugs(28, DBG_IMPORTANT, "aclMatchUserMaxIP: user '" << auth_user_request->username() << "' tries to use too many IP addresses (max " << maximum << " allowed)!");
 
     /* this is a match */
-    if (flags.strict) {
+    if (flags.isSet(ACL_F_STRICT)) {
         /*
          * simply deny access - the user name is already associated with
          * the request
@@ -154,9 +150,6 @@
 
     wordlist *W = NULL;
 
-    if (flags.strict)
-        wordlistAdd(&W, "-s");
-
     char buf[128];
 
     snprintf(buf, sizeof(buf), "%lu", (unsigned long int) maximum);
diff -u -r -N squid-3.4.1/src/auth/AclMaxUserIp.h squid-3.4.2/src/auth/AclMaxUserIp.h
--- squid-3.4.1/src/auth/AclMaxUserIp.h	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/auth/AclMaxUserIp.h	2013-12-31 00:33:27.000000000 +1300
@@ -62,21 +62,16 @@
 
     int getMaximum() const {return maximum;}
 
-    int getStrict() const {return flags.strict;}
+    bool getStrict() const {return flags.isSet(ACL_F_STRICT);}
 
 private:
     static Prototype RegistryProtoype;
     static ACLMaxUserIP RegistryEntry_;
+    static ACLFlag  SupportedFlags[];
 
     int match(Auth::UserRequest::Pointer, Ip::Address const &);
     char const *class_;
     int maximum;
-
-    struct Flags {
-        Flags() : strict(false) {}
-
-        bool strict;
-    } flags;
 };
 
 MEMPROXY_CLASS_INLINE(ACLMaxUserIP);
diff -u -r -N squid-3.4.1/src/auth/basic/Makefile.in squid-3.4.2/src/auth/basic/Makefile.in
--- squid-3.4.1/src/auth/basic/Makefile.in	2013-12-09 14:21:46.000000000 +1300
+++ squid-3.4.2/src/auth/basic/Makefile.in	2013-12-31 00:34:04.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libbasic.la
 libbasic_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/auth/digest/Makefile.in squid-3.4.2/src/auth/digest/Makefile.in
--- squid-3.4.1/src/auth/digest/Makefile.in	2013-12-09 14:21:46.000000000 +1300
+++ squid-3.4.2/src/auth/digest/Makefile.in	2013-12-31 00:34:04.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libdigest.la
 libdigest_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/auth/Makefile.in squid-3.4.2/src/auth/Makefile.in
--- squid-3.4.1/src/auth/Makefile.in	2013-12-09 14:21:45.000000000 +1300
+++ squid-3.4.2/src/auth/Makefile.in	2013-12-31 00:34:03.000000000 +1300
@@ -398,7 +398,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 SUBDIRS = $(AUTH_MODULES)
 DIST_SUBDIRS = basic digest negotiate ntlm
diff -u -r -N squid-3.4.1/src/auth/negotiate/Makefile.in squid-3.4.2/src/auth/negotiate/Makefile.in
--- squid-3.4.1/src/auth/negotiate/Makefile.in	2013-12-09 14:21:46.000000000 +1300
+++ squid-3.4.2/src/auth/negotiate/Makefile.in	2013-12-31 00:34:04.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libnegotiate.la
 libnegotiate_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/auth/ntlm/Makefile.in squid-3.4.2/src/auth/ntlm/Makefile.in
--- squid-3.4.1/src/auth/ntlm/Makefile.in	2013-12-09 14:21:46.000000000 +1300
+++ squid-3.4.2/src/auth/ntlm/Makefile.in	2013-12-31 00:34:04.000000000 +1300
@@ -357,7 +357,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libntlm.la
 libntlm_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/base/Makefile.in squid-3.4.2/src/base/Makefile.in
--- squid-3.4.1/src/base/Makefile.in	2013-12-09 14:21:47.000000000 +1300
+++ squid-3.4.2/src/base/Makefile.in	2013-12-31 00:34:05.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libbase.la
 libbase_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/cf.data.pre squid-3.4.2/src/cf.data.pre
--- squid-3.4.1/src/cf.data.pre	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/cf.data.pre	2013-12-31 00:33:27.000000000 +1300
@@ -2661,8 +2661,8 @@
 		concurrency=
 	
 	The number of requests each certificate validator helper can handle in
-	parallel. Defaults to 0 which indicates the certficate validator
-	is a old-style single threaded redirector.
+	parallel. A value of 0 indicates the certficate validator does not
+	support concurrency. Defaults to 1.
 	
 	When this directive is set to a value >= 1 then the protocol
 	used to communicate with the helper is modified to include
diff -u -r -N squid-3.4.1/src/client_side_reply.cc squid-3.4.2/src/client_side_reply.cc
--- squid-3.4.1/src/client_side_reply.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/client_side_reply.cc	2013-12-31 00:33:27.000000000 +1300
@@ -69,6 +69,8 @@
 #include "esi/Esi.h"
 #endif
 
+#include <memory>
+
 CBDATA_CLASS_INIT(clientReplyContext);
 
 /* Local functions */
@@ -487,6 +489,7 @@
 
     if (strcmp(e->mem_obj->url, http->request->storeId()) != 0) {
         debugs(33, DBG_IMPORTANT, "clientProcessHit: URL mismatch, '" << e->mem_obj->url << "' != '" << http->request->storeId() << "'");
+        http->logType = LOG_TCP_MISS; // we lack a more precise LOG_*_MISS code
         processMiss();
         return;
     }
@@ -518,6 +521,7 @@
     case VARY_CANCEL:
         /* varyEvaluateMatch found a object loop. Process as miss */
         debugs(88, DBG_IMPORTANT, "clientProcessHit: Vary object loop!");
+        http->logType = LOG_TCP_MISS; // we lack a more precise LOG_*_MISS code
         processMiss();
         return;
     }
diff -u -r -N squid-3.4.1/src/comm/Makefile.in squid-3.4.2/src/comm/Makefile.in
--- squid-3.4.1/src/comm/Makefile.in	2013-12-09 14:21:47.000000000 +1300
+++ squid-3.4.2/src/comm/Makefile.in	2013-12-31 00:34:05.000000000 +1300
@@ -360,7 +360,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libcomm.la
 libcomm_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/Common.am squid-3.4.2/src/Common.am
--- squid-3.4.1/src/Common.am	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/Common.am	2013-12-31 00:33:27.000000000 +1300
@@ -43,7 +43,7 @@
 endif
 
 ## Because compatibility is almost universal. And the link order is important.
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 
 ## Some helpers are written in Perl and need the local shell defined properly
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
diff -u -r -N squid-3.4.1/src/esi/Makefile.in squid-3.4.2/src/esi/Makefile.in
--- squid-3.4.1/src/esi/Makefile.in	2013-12-09 14:21:47.000000000 +1300
+++ squid-3.4.2/src/esi/Makefile.in	2013-12-31 00:34:05.000000000 +1300
@@ -377,7 +377,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libesi.la
 ESI_PARSER_SOURCES = CustomParser.cc CustomParser.h $(am__append_2) \
diff -u -r -N squid-3.4.1/src/eui/Makefile.in squid-3.4.2/src/eui/Makefile.in
--- squid-3.4.1/src/eui/Makefile.in	2013-12-09 14:21:47.000000000 +1300
+++ squid-3.4.2/src/eui/Makefile.in	2013-12-31 00:34:05.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libeui.la
 libeui_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/format/Makefile.in squid-3.4.2/src/format/Makefile.in
--- squid-3.4.1/src/format/Makefile.in	2013-12-09 14:21:47.000000000 +1300
+++ squid-3.4.2/src/format/Makefile.in	2013-12-31 00:34:05.000000000 +1300
@@ -357,7 +357,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libformat.la
 libformat_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/fs/Makefile.in squid-3.4.2/src/fs/Makefile.in
--- squid-3.4.1/src/fs/Makefile.in	2013-12-09 14:21:48.000000000 +1300
+++ squid-3.4.2/src/fs/Makefile.in	2013-12-31 00:34:06.000000000 +1300
@@ -380,7 +380,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 EXTRA_LTLIBRARIES = libaufs.la libdiskd.la libcoss.la libufs.la librock.la
 noinst_LTLIBRARIES = $(STORE_LIBS_TO_BUILD) libfs.la
diff -u -r -N squid-3.4.1/src/ftp.cc squid-3.4.2/src/ftp.cc
--- squid-3.4.1/src/ftp.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/ftp.cc	2013-12-31 00:33:27.000000000 +1300
@@ -3051,6 +3051,13 @@
     debugs(9, 3, HERE);
 
     if (code == 125 || (code == 150 && Comm::IsConnOpen(data.conn))) {
+        if (!originalRequest()->body_pipe) {
+            debugs(9, 3, "zero-size STOR?");
+            state = WRITING_DATA; // make ftpWriteTransferDone() responsible
+            dataComplete(); // XXX: keep in sync with doneSendingRequestBody()
+            return;
+        }
+
         if (!startRequestBodyFlow()) { // register to receive body data
             ftpFail(this);
             return;
diff -u -r -N squid-3.4.1/src/HelperReply.cc squid-3.4.2/src/HelperReply.cc
--- squid-3.4.1/src/HelperReply.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/HelperReply.cc	2013-12-31 00:33:27.000000000 +1300
@@ -127,13 +127,33 @@
     }
 }
 
+/// restrict key names to alphanumeric, hyphen, underscore characters
+static bool
+isKeyNameChar(char c)
+{
+    if (c >= 'a' && c <= 'z')
+        return true;
+
+    if (c >= 'A' && c <= 'Z')
+        return true;
+
+    if (c >= '0' && c <= '9')
+        return true;
+
+    if (c == '-' || c == '_')
+        return true;
+
+    // prevent other characters matching the key=value
+    return false;
+}
+
 void
 HelperReply::parseResponseKeys()
 {
     // parse a "key=value" pair off the 'other()' buffer.
     while (other().hasContent()) {
         char *p = modifiableOther().content();
-        while (*p && *p != '=' && *p != ' ') ++p;
+        while (*p && isKeyNameChar(*p)) ++p;
         if (*p != '=')
             return; // done. Not a key.
 
diff -u -r -N squid-3.4.1/src/http/Makefile.in squid-3.4.2/src/http/Makefile.in
--- squid-3.4.1/src/http/Makefile.in	2013-12-09 14:21:48.000000000 +1300
+++ squid-3.4.2/src/http/Makefile.in	2013-12-31 00:34:06.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libsquid-http.la
 libsquid_http_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/icmp/Makefile.in squid-3.4.2/src/icmp/Makefile.in
--- squid-3.4.1/src/icmp/Makefile.in	2013-12-09 14:21:48.000000000 +1300
+++ squid-3.4.2/src/icmp/Makefile.in	2013-12-31 00:34:06.000000000 +1300
@@ -123,7 +123,8 @@
 	stub_HelperChildConfig.$(OBJEXT)
 pinger_OBJECTS = $(am_pinger_OBJECTS) $(nodist_pinger_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 pinger_DEPENDENCIES = libicmp-core.la ../ip/libip.la \
 	$(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3)
@@ -393,7 +394,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 @ENABLE_PINGER_FALSE@PINGER = 
 
diff -u -r -N squid-3.4.1/src/ident/Makefile.in squid-3.4.2/src/ident/Makefile.in
--- squid-3.4.1/src/ident/Makefile.in	2013-12-09 14:21:49.000000000 +1300
+++ squid-3.4.2/src/ident/Makefile.in	2013-12-31 00:34:06.000000000 +1300
@@ -357,7 +357,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libident.la
 libident_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/ip/Makefile.in squid-3.4.2/src/ip/Makefile.in
--- squid-3.4.1/src/ip/Makefile.in	2013-12-09 14:21:49.000000000 +1300
+++ squid-3.4.2/src/ip/Makefile.in	2013-12-31 00:34:07.000000000 +1300
@@ -114,7 +114,8 @@
 	$(nodist_testIpAddress_OBJECTS)
 am__DEPENDENCIES_1 =
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_2 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_3 = $(am__DEPENDENCIES_2)
+am__DEPENDENCIES_3 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_2)
 testIpAddress_DEPENDENCIES = libip.la $(am__DEPENDENCIES_1) \
 	$(am__DEPENDENCIES_3) $(am__DEPENDENCIES_1) \
 	$(am__DEPENDENCIES_1)
@@ -372,7 +373,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libip.la
 libip_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/ipc/Makefile.in squid-3.4.2/src/ipc/Makefile.in
--- squid-3.4.1/src/ipc/Makefile.in	2013-12-09 14:21:49.000000000 +1300
+++ squid-3.4.2/src/ipc/Makefile.in	2013-12-31 00:34:07.000000000 +1300
@@ -362,7 +362,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libipc.la
 libipc_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/ipcache.cc squid-3.4.2/src/ipcache.cc
--- squid-3.4.1/src/ipcache.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/ipcache.cc	2013-12-31 00:33:27.000000000 +1300
@@ -1071,7 +1071,6 @@
     if (!ia->bad_mask[k]) {
         ia->bad_mask[k] = TRUE;
         ++ia->badcount;
-        i->expires = min(squid_curtime + max((time_t)60, Config.negativeDnsTtl), i->expires);
         debugs(14, 2, "ipcacheMarkBadAddr: " << name << " " << addr );
     }
 
diff -u -r -N squid-3.4.1/src/log/Makefile.in squid-3.4.2/src/log/Makefile.in
--- squid-3.4.1/src/log/Makefile.in	2013-12-09 14:21:50.000000000 +1300
+++ squid-3.4.2/src/log/Makefile.in	2013-12-31 00:34:07.000000000 +1300
@@ -361,7 +361,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = liblog.la
 liblog_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/Makefile.am squid-3.4.2/src/Makefile.am
--- squid-3.4.1/src/Makefile.am	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/Makefile.am	2013-12-31 00:33:27.000000000 +1300
@@ -940,7 +940,7 @@
 # Make location configure settings available to the code
 DEFS += -DDEFAULT_CONFIG_FILE=\"$(DEFAULT_CONFIG_FILE)\" -DDEFAULT_SQUID_DATA_DIR=\"$(datadir)\" -DDEFAULT_SQUID_CONFIG_DIR=\"$(sysconfdir)\"
 
-snmp_core.o snmp_agent.o: ../snmplib/libsnmplib.a $(top_srcdir)/include/cache_snmp.h
+snmp_core.o snmp_agent.o: ../snmplib/libsnmplib.la $(top_srcdir)/include/cache_snmp.h
 
 globals.cc: globals.h mk-globals-c.awk
 	$(AWK) -f $(srcdir)/mk-globals-c.awk < $(srcdir)/globals.h > $@ || ($(RM) -f $@ && exit 1)
diff -u -r -N squid-3.4.1/src/Makefile.in squid-3.4.2/src/Makefile.in
--- squid-3.4.1/src/Makefile.in	2013-12-09 14:21:43.000000000 +1300
+++ squid-3.4.2/src/Makefile.in	2013-12-31 00:34:02.000000000 +1300
@@ -229,7 +229,8 @@
 	$(am_DiskIO_DiskDaemon_diskd_OBJECTS) \
 	$(nodist_DiskIO_DiskDaemon_diskd_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 DiskIO_DiskDaemon_diskd_DEPENDENCIES =  \
 	$(top_builddir)/lib/libmisccontainers.la \
@@ -2254,7 +2255,7 @@
 	-I$(top_builddir)/src $(am__append_10) $(KRB5INCS)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 AUTOMAKE_OPTIONS = subdir-objects
 @ENABLE_DNSHELPER_FALSE@DNSSOURCE = dns_internal.cc SquidDns.h \
@@ -7258,7 +7259,7 @@
 DiskIO/DiskIOModules_gen.cc: Makefile
 	$(SHELL) $(srcdir)/DiskIO/modules.sh $(DISK_MODULES) > DiskIO/DiskIOModules_gen.cc
 
-snmp_core.o snmp_agent.o: ../snmplib/libsnmplib.a $(top_srcdir)/include/cache_snmp.h
+snmp_core.o snmp_agent.o: ../snmplib/libsnmplib.la $(top_srcdir)/include/cache_snmp.h
 
 globals.cc: globals.h mk-globals-c.awk
 	$(AWK) -f $(srcdir)/mk-globals-c.awk < $(srcdir)/globals.h > $@ || ($(RM) -f $@ && exit 1)
diff -u -r -N squid-3.4.1/src/MemStore.cc squid-3.4.2/src/MemStore.cc
--- squid-3.4.1/src/MemStore.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/MemStore.cc	2013-12-31 00:33:27.000000000 +1300
@@ -310,6 +310,12 @@
         return;
     }
 
+    if (e.mem_obj->vary_headers) {
+        // XXX: We must store/load SerialisedMetaData to cache Vary in RAM
+        debugs(20, 5, "Vary not yet supported: " << e.mem_obj->vary_headers);
+        return;
+    }
+
     keep(e); // may still fail
 }
 
diff -u -r -N squid-3.4.1/src/mgr/Makefile.in squid-3.4.2/src/mgr/Makefile.in
--- squid-3.4.1/src/mgr/Makefile.in	2013-12-09 14:21:50.000000000 +1300
+++ squid-3.4.2/src/mgr/Makefile.in	2013-12-31 00:34:07.000000000 +1300
@@ -362,7 +362,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libmgr.la
 libmgr_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/repl/Makefile.in squid-3.4.2/src/repl/Makefile.in
--- squid-3.4.1/src/repl/Makefile.in	2013-12-09 14:21:50.000000000 +1300
+++ squid-3.4.2/src/repl/Makefile.in	2013-12-31 00:34:08.000000000 +1300
@@ -367,7 +367,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 AUTOMAKE_OPTIONS = subdir-objects
 
diff -u -r -N squid-3.4.1/src/snmp/Makefile.in squid-3.4.2/src/snmp/Makefile.in
--- squid-3.4.1/src/snmp/Makefile.in	2013-12-09 14:21:50.000000000 +1300
+++ squid-3.4.2/src/snmp/Makefile.in	2013-12-31 00:34:08.000000000 +1300
@@ -358,7 +358,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libsnmp.la
 libsnmp_la_SOURCES = \
diff -u -r -N squid-3.4.1/src/SquidString.h squid-3.4.2/src/SquidString.h
--- squid-3.4.1/src/SquidString.h	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/SquidString.h	2013-12-31 00:33:27.000000000 +1300
@@ -87,7 +87,7 @@
     ~String();
 
     typedef size_t size_type; //storage size intentionally unspecified
-    const static size_type npos = -1;
+    const static size_type npos = static_cast<size_type>(-1);
 
     String &operator =(char const *);
     String &operator =(String const &);
diff -u -r -N squid-3.4.1/src/ssl/Config.cc squid-3.4.2/src/ssl/Config.cc
--- squid-3.4.1/src/ssl/Config.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/ssl/Config.cc	2013-12-31 00:33:27.000000000 +1300
@@ -3,6 +3,15 @@
 
 Ssl::Config Ssl::TheConfig;
 
+Ssl::Config::Config():
+#if USE_SSL_CRTD
+            ssl_crtd(NULL),
+#endif
+            ssl_crt_validator(NULL)
+{ 
+    ssl_crt_validator_Children.concurrency = 1;
+}
+
 Ssl::Config::~Config()
 {
 #if USE_SSL_CRTD
diff -u -r -N squid-3.4.1/src/ssl/Config.h squid-3.4.2/src/ssl/Config.h
--- squid-3.4.1/src/ssl/Config.h	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/ssl/Config.h	2013-12-31 00:33:27.000000000 +1300
@@ -16,12 +16,7 @@
 #endif
     char *ssl_crt_validator;
     HelperChildConfig ssl_crt_validator_Children;
-    Config():
-#if USE_SSL_CRTD
-            ssl_crtd(NULL),
-#endif
-            ssl_crt_validator(NULL) {}
-
+    Config();
     ~Config();
 private:
     Config(const Config &); // not implemented
diff -u -r -N squid-3.4.1/src/ssl/Makefile.in squid-3.4.2/src/ssl/Makefile.in
--- squid-3.4.1/src/ssl/Makefile.in	2013-12-09 14:21:50.000000000 +1300
+++ squid-3.4.2/src/ssl/Makefile.in	2013-12-31 00:34:08.000000000 +1300
@@ -124,7 +124,8 @@
 ssl_crtd_OBJECTS = $(am_ssl_crtd_OBJECTS)
 am__DEPENDENCIES_1 =
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_2 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_3 = $(am__DEPENDENCIES_2)
+am__DEPENDENCIES_3 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_2)
 @USE_SSL_CRTD_TRUE@ssl_crtd_DEPENDENCIES = libsslutil.la \
 @USE_SSL_CRTD_TRUE@	$(am__DEPENDENCIES_1) $(am__DEPENDENCIES_3)
 DEFAULT_INCLUDES = 
@@ -380,7 +381,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 noinst_LTLIBRARIES = libsslsquid.la libsslutil.la
 EXTRA_DIST = \
diff -u -r -N squid-3.4.1/src/store.cc squid-3.4.2/src/store.cc
--- squid-3.4.1/src/store.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/store.cc	2013-12-31 00:33:27.000000000 +1300
@@ -795,12 +795,14 @@
             }
 
 #endif
-            pe->replaceHttpReply(rep);
+            pe->replaceHttpReply(rep, false); // no write until key is public
 
             pe->timestampsSet();
 
             pe->makePublic();
 
+            pe->startWriting(); // after makePublic()
+
             pe->complete();
 
             pe->unlock();
diff -u -r -N squid-3.4.1/src/String.cc squid-3.4.2/src/String.cc
--- squid-3.4.1/src/String.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/String.cc	2013-12-31 00:33:27.000000000 +1300
@@ -376,7 +376,8 @@
         switch (ch) {
 
         case '\\':
-            ++p;
+            if (quoted)
+                ++p;
 
             switch (*p) {
 
diff -u -r -N squid-3.4.1/src/tests/stub_libsslsquid.cc squid-3.4.2/src/tests/stub_libsslsquid.cc
--- squid-3.4.1/src/tests/stub_libsslsquid.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/tests/stub_libsslsquid.cc	2013-12-31 00:33:27.000000000 +1300
@@ -10,6 +10,15 @@
 #include "tests/STUB.h"
 
 #include "ssl/Config.h"
+Ssl::Config::Config():
+#if USE_SSL_CRTD
+            ssl_crtd(NULL),
+#endif
+            ssl_crt_validator(NULL)
+{
+    ssl_crt_validator_Children.concurrency = 1;
+    STUB_NOP
+}
 Ssl::Config::~Config() STUB_NOP
 Ssl::Config Ssl::TheConfig;
 
diff -u -r -N squid-3.4.1/src/tests/testACLMaxUserIP.cc squid-3.4.2/src/tests/testACLMaxUserIP.cc
--- squid-3.4.1/src/tests/testACLMaxUserIP.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/tests/testACLMaxUserIP.cc	2013-12-31 00:33:27.000000000 +1300
@@ -6,6 +6,7 @@
 
 #include "testACLMaxUserIP.h"
 #include "auth/AclMaxUserIp.h"
+#include "ConfigParser.h"
 
 #if HAVE_STDEXCEPT
 #include <stdexcept>
@@ -29,14 +30,13 @@
 testACLMaxUserIP::testParseLine()
 {
     /* a config line to pass with a lead-in token to seed the parser. */
-    char * line = xstrdup("token -s 1");
+    char * line = xstrdup("max_user_ip 1");
     /* seed the parser */
     strtok(line, w_space);
     ACLMaxUserIP anACL("max_user_ip");
     anACL.parse();
-    /* we want a maximum of one, and strict to be true */
+    /* we want a maximum of one */
     CPPUNIT_ASSERT(anACL.getMaximum() == 1);
-    CPPUNIT_ASSERT(anACL.getStrict() == true);
     /* the acl must be vaid */
     CPPUNIT_ASSERT(anACL.valid());
     xfree(line);
diff -u -r -N squid-3.4.1/src/wccp2.cc squid-3.4.2/src/wccp2.cc
--- squid-3.4.1/src/wccp2.cc	2013-12-09 14:20:54.000000000 +1300
+++ squid-3.4.2/src/wccp2.cc	2013-12-31 00:33:27.000000000 +1300
@@ -1172,14 +1172,13 @@
 
     /* FIXME INET6 : drop conversion boundary */
     Ip::Address from_tmp;
+    from_tmp.setIPv4();
 
     len = comm_udp_recvfrom(sock,
                             &wccp2_i_see_you,
                             WCCP_RESPONSE_SIZE,
                             0,
                             from_tmp);
-    /* FIXME INET6 : drop conversion boundary */
-    from_tmp.getSockAddr(from);
 
     if (len < 0)
         return;
@@ -1190,6 +1189,9 @@
     if (ntohl(wccp2_i_see_you.type) != WCCP2_I_SEE_YOU)
         return;
 
+    /* FIXME INET6 : drop conversion boundary */
+    from_tmp.getSockAddr(from);
+
     debugs(80, 3, "Incoming WCCPv2 I_SEE_YOU length " << ntohs(wccp2_i_see_you.length) << ".");
 
     /* Record the total data length */
diff -u -r -N squid-3.4.1/test-suite/Makefile.in squid-3.4.2/test-suite/Makefile.in
--- squid-3.4.1/test-suite/Makefile.in	2013-12-09 14:21:51.000000000 +1300
+++ squid-3.4.2/test-suite/Makefile.in	2013-12-31 00:34:08.000000000 +1300
@@ -117,7 +117,8 @@
 am_ESIExpressions_OBJECTS = ESIExpressions.$(OBJEXT) $(am__objects_1)
 ESIExpressions_OBJECTS = $(am_ESIExpressions_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 am__DEPENDENCIES_4 = $(top_builddir)/src/globals.o \
 	$(top_builddir)/src/time.o $(top_builddir)/lib/libmiscutil.la \
@@ -437,7 +438,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 AUTOMAKE_OPTIONS = subdir-objects
 LDADD = \
diff -u -r -N squid-3.4.1/tools/Makefile.in squid-3.4.2/tools/Makefile.in
--- squid-3.4.1/tools/Makefile.in	2013-12-09 14:21:51.000000000 +1300
+++ squid-3.4.2/tools/Makefile.in	2013-12-31 00:34:09.000000000 +1300
@@ -124,7 +124,8 @@
 cachemgr__CGIEXT__OBJECTS = $(am_cachemgr__CGIEXT__OBJECTS)
 cachemgr__CGIEXT__LDADD = $(LDADD)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 cachemgr__CGIEXT__DEPENDENCIES = $(top_builddir)/src/ip/libip.la \
 	$(top_builddir)/lib/libmiscencoding.la \
@@ -447,7 +448,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1) -I$(srcdir)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 AUTOMAKE_OPTIONS = subdir-objects
 SUBDIRS = purge
diff -u -r -N squid-3.4.1/tools/purge/Makefile.in squid-3.4.2/tools/purge/Makefile.in
--- squid-3.4.1/tools/purge/Makefile.in	2013-12-09 14:21:52.000000000 +1300
+++ squid-3.4.2/tools/purge/Makefile.in	2013-12-31 00:34:09.000000000 +1300
@@ -111,7 +111,8 @@
 	purge.$(OBJEXT)
 purge_OBJECTS = $(am_purge_OBJECTS)
 @ENABLE_XPROF_STATS_TRUE@am__DEPENDENCIES_1 = $(top_builddir)/lib/profiler/libprofiler.la
-am__DEPENDENCIES_2 = $(am__DEPENDENCIES_1)
+am__DEPENDENCIES_2 = $(top_builddir)/compat/libcompat-squid.la \
+	$(am__DEPENDENCIES_1)
 am__DEPENDENCIES_3 =
 purge_DEPENDENCIES = $(am__DEPENDENCIES_2) $(am__DEPENDENCIES_3)
 DEFAULT_INCLUDES = 
@@ -364,7 +365,7 @@
 	$(SQUID_CPPUNIT_INC) $(KRB5INCS) $(am__append_1)
 @ENABLE_XPROF_STATS_FALSE@LIBPROFILER = 
 @ENABLE_XPROF_STATS_TRUE@LIBPROFILER = $(top_builddir)/lib/profiler/libprofiler.la
-COMPAT_LIB = -L$(top_builddir)/compat -lcompat-squid $(LIBPROFILER)
+COMPAT_LIB = $(top_builddir)/compat/libcompat-squid.la $(LIBPROFILER)
 subst_perlshell = sed -e 's,[@]PERL[@],$(PERL),g' <$(srcdir)/$@.pl.in >$@ || ($(RM) -f $@ ; exit 1)
 purge_SOURCES = \
 	convert.cc \
